@@ -1,15 +1,15 @@
 #[macro_export]
 macro_rules! implement_cron {
     () => {
-        static mut CRON: Option<ic_cron::Cron> = None;
+        static mut CRON: Option<ic_cron::types::Cron> = None;
 
         #[inline(always)]
-        pub fn get_cron_state() -> &'static mut ic_cron::Cron {
+        pub fn get_cron_state() -> &'static mut ic_cron::types::Cron {
             unsafe {
                 match CRON.as_mut() {
                     Some(cron) => cron,
                     None => {
-                        CRON = Some(ic_cron::Cron::default());
+                        CRON = Some(ic_cron::types::Cron::default());
                         get_cron_state()
                     }
                 }
@@ -17,19 +17,14 @@ macro_rules! implement_cron {
         }
 
         pub fn cron_enqueue<Tuple: ic_cdk::export::candid::utils::ArgumentEncoder>(
-            endpoint: union_utils::RemoteCallEndpoint,
-            args: Tuple,
-            cycles: u64,
+            kind: u8,
+            payload: ic_cron::types::Task,
             scheduling_interval: ic_cron::types::SchedulingInterval,
         ) -> ic_cdk::export::candid::Result<ic_cron::types::TaskId> {
             let cron = get_cron_state();
-            let task = cron.scheduler.enqueue(
-                endpoint,
-                args,
-                cycles,
-                scheduling_interval,
-                ic_cdk::api::time(),
-            );
+            let task =
+                cron.scheduler
+                    .enqueue(kind, payload, scheduling_interval, ic_cdk::api::time());
 
             if !cron.is_running {
                 cron.is_running = true;
@@ -41,7 +36,9 @@ macro_rules! implement_cron {
         }
 
         #[inline(always)]
-        pub fn cron_dequeue(task_id: ic_cron::types::TaskId) -> Option<ic_cron::types::Task> {
+        pub fn cron_dequeue(
+            task_id: ic_cron::types::TaskId,
+        ) -> Option<ic_cron::types::ScheduledTask> {
             get_cron_state().scheduler.dequeue(task_id)
         }
 
@@ -64,7 +61,7 @@ macro_rules! implement_cron {
             cron.scheduler
                 .iterate(ic_cdk::api::time())
                 .into_iter()
-                .for_each(ic_cron::exec_cron_task);
+                .for_each(_cron_task_handler);
 
             if cron.scheduler.is_empty() {
                 cron.is_running = false;
@@ -74,3 +71,20 @@ macro_rules! implement_cron {
         }
     };
 }
+
+#[cfg(test)]
+mod tests {
+    use crate as ic_cron;
+    use crate::implement_cron;
+    use crate::types::ScheduledTask;
+
+    fn _cron_task_handler(task: ScheduledTask) {
+        match task.get_kind() {
+            0u8 => {}
+            1u8 => {}
+            _ => {}
+        }
+    }
+
+    implement_cron!();
+}
